@@ -2,9 +2,14 @@
 package State::Machine::Failure::Transition::Execution;
 
 use Bubblegum::Class;
+use Function::Parameters;
 
 extends 'State::Machine::Failure::Transition';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
+
+method _build_message {
+    "Transition execution failure."
+}
 
 1;
